#[non_exhaustive]pub enum Confidence {
None,
Low,
Medium,
High,
}Expand description
Coarse confidence level derived from the warmup state and baseline comparison.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
No data has been observed yet.
Low
The model is still warming up or has degraded.
Medium
The model is usable but not yet stable.
High
The model is stable and beating the baseline.
Implementations