pub struct SelectorConfig {
pub window_size: usize,
pub cooling_period: u64,
pub min_samples_before_switch: u64,
}Expand description
Configuration for OnlineModelSelector.
Fields
window_size: usizeRolling window size passed to the underlying BaselineComparator.
Must be greater than zero.
cooling_period: u64Number of samples that must be recorded on the current best model before another switch is allowed.
min_samples_before_switch: u64Minimum number of samples a model must have before it can be selected as the best.