pub struct WarmupConfig {
pub warming_up_threshold: u64,
pub usable_threshold: u64,
pub stable_threshold: u64,
pub degraded_error_ratio: f64,
}Expand description
Configuration for WarmupTracker.
Fields
warming_up_threshold: u64Number of samples below which the model is considered WarmupState::WarmingUp.
usable_threshold: u64Number of samples at which the model transitions from warming up to
WarmupState::Usable (when no error comparison applies).
stable_threshold: u64Number of samples required (along with beating the baseline) for
WarmupState::Stable.
degraded_error_ratio: f64Ratio by which the recent error may exceed the baseline before the
model is considered WarmupState::Degraded.