DriftConsensusConfig

Struct DriftConsensusConfig 

#[non_exhaustive]
pub struct DriftConsensusConfig { pub minimum_warning_votes: usize, pub minimum_drift_votes: usize, pub confirmation_windows: u64, pub clear_windows: u64, pub cooldown_windows: u64, pub event_merge_horizon: u64, pub warming_windows: u64, pub max_detectors: usize, }
Configuration for DriftConsensus.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
minimum_warning_votes: usize

Warning-or-drift votes required for a warning candidate.

minimum_drift_votes: usize

Drift votes required for a confirmed drift candidate.

confirmation_windows: u64

Consecutive candidate windows required to change level.

clear_windows: u64

Consecutive complete, stable windows required to clear a level.

cooldown_windows: u64

Windows after an event during which another event is suppressed.

event_merge_horizon: u64

Maximum distance at which a repeated event is merged into the last one.

warming_windows: u64

Initial complete windows reported as warming.

max_detectors: usize

Maximum votes and retained detector identifiers.

Implementations

Source

impl DriftConsensusConfig

pub fn validate(&self) -> Result<(), RillError>

Validate thresholds and capacity bounds.