DriftStrategy

Trait DriftStrategy 

pub trait DriftStrategy {
    // Required method
    fn decide(&self, level: DriftLevel, samples_seen: u64) -> DriftAction;
}
Strategy for deciding what action to take when a drift detector reports a change.

Implementations may be stateless (like StaticStrategy) or stateful (e.g. a strategy that escalates from NotifyOnly to ResetModel after repeated warnings).

Required Methods

fn decide(&self, level: DriftLevel, samples_seen: u64) -> DriftAction

Decide the action for the given drift level and sample count.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors