BinaryLogLoss

Struct BinaryLogLoss 

pub struct BinaryLogLoss { /* private fields */ }
Binary cross-entropy (log) loss.

Implementations

Source

impl BinaryLogLoss

pub const fn new() -> Self

Create a new log loss with the default epsilon.

pub fn with_epsilon(epsilon: f64) -> Result<Self, RillError>

Create a new log loss with a custom epsilon.

pub const fn epsilon(&self) -> f64

The configured epsilon.

pub fn clip(&self, p: f64) -> f64

Clip a probability to [epsilon, 1 - epsilon].

pub fn loss(&self, probability: f64, target: bool) -> f64

Compute the log loss given a probability and boolean target.

pub fn gradient_wrt_logit(&self, probability: f64, target: bool) -> f64

Gradient of the loss w.r.t. the logit z = log(p / (1 - p)).

This equals p - y where p = sigmoid(z).