Module models

Module models 

Online models: baseline regressors, linear regression, logistic regression, Naive Bayes classifiers, and FTRL-Proximal for sparse features.

Structs

BaselineConfig
Configuration shared by baseline regressors.
BernoulliNaiveBayes
Online Bernoulli Naive Bayes classifier.
ExponentiallyWeightedMeanRegressor
A regressor that predicts an exponentially weighted mean of targets.
FtrlClassifier
FTRL binary classifier with log loss.
FtrlConfig
Configuration for FTRL models.
FtrlRegressor
FTRL regressor with squared loss.
FtrlResourceDiagnostics
Bounded-resource diagnostics for a sparse FTRL model.
GaussianNaiveBayes
Online Gaussian Naive Bayes classifier.
LastValueRegressor
A regressor that always predicts the last observed target.
LinearRegression
Online linear regression model.
LinearRegressionConfig
Configuration for LinearRegression.
LogisticRegression
Online logistic regression model.
LogisticRegressionConfig
Configuration for LogisticRegression.
MeanRegressor
A regressor that always predicts the running mean of observed targets.
MultinomialNaiveBayes
Online Multinomial Naive Bayes classifier.
NaiveBayesConfig
Configuration for Naive Bayes classifiers.

Enums

NewFeaturePolicy
Policy for handling new FeatureIds once FtrlConfig::max_features has been reached.