pub struct GaussianNaiveBayes { /* private fields */ }Expand description
Online Gaussian Naive Bayes classifier.
Assumes features are conditionally independent given the class, and each feature follows a Gaussian distribution per class. Uses Welford’s algorithm for numerically stable variance updates.
Examples
use rill_ml::models::GaussianNaiveBayes;
use rill_ml::OnlineBinaryClassifier;
let mut model = GaussianNaiveBayes::new(2, Default::default()).unwrap();
model.learn(&[1.0, 2.0], true).unwrap();
model.learn(&[-1.0, -2.0], false).unwrap();
let proba = model.predict_proba(&[0.5, 1.0]).unwrap();
assert!(proba > 0.0 && proba < 1.0);Implementations