pub struct OrdinalEncoder { /* private fields */ }Expand description
Online ordinal encoder for string features.
Categories are discovered incrementally via update_strs
and kept in sorted order. transform_strs maps each
string to its index in the sorted category list.
Implementations
Sourceimpl OrdinalEncoder
impl OrdinalEncoder
Sourcepub fn categories(&self) -> &[String]
pub fn categories(&self) -> &[String]
The known categories, kept in sorted order.
Sourcepub fn category_index(&self, category: &str) -> Option<usize>
pub fn category_index(&self, category: &str) -> Option<usize>
Find the index of category using binary search.
Sourcepub fn fit_one(&mut self, category: &str)
pub fn fit_one(&mut self, category: &str)
Add a category if not already present, keeping the list sorted.
Sourcepub fn transform_strs(&self, features: &[&str]) -> Result<Vec<f64>, RillError>
pub fn transform_strs(&self, features: &[&str]) -> Result<Vec<f64>, RillError>
Encode each string as its category index (as f64).
Output length = features.len() (one value per input string).
Errors
RillError::EmptyFeaturesiffeaturesis empty.RillError::UnknownCategoryif any string is not in the known categories.
Before any category has been seen, returns an empty vector.
Sourcepub fn update_strs(&mut self, features: &[&str]) -> Result<(), RillError>
pub fn update_strs(&mut self, features: &[&str]) -> Result<(), RillError>
Add all new categories from features and increment samples_seen.
Errors
Returns RillError::EmptyFeatures if features is empty.
Sourcepub fn samples_seen(&self) -> u64
pub fn samples_seen(&self) -> u64
How many samples have been seen.