DecisionReplayReport

Struct DecisionReplayReport 

pub struct DecisionReplayReport {
Show 15 fields pub cumulative_reward: f64, pub approximate_regret: f64, pub baseline_cumulative_reward: f64, pub reward_over_baseline: f64, pub per_arm_pulls: Vec<u64>, pub pending: usize, pub completed: usize, pub expired: usize, pub missing_feedback: usize, pub duplicate_feedback: usize, pub rejected: usize, pub generation_transitions: usize, pub drift_events: usize, pub feedback_latency: Option<FeedbackLatencySummary>, pub deterministic_replay_digest: String,
}
Available on crate feature bandit only.
Replay result. Regret is only accumulated for records that provide an optimal_reward; baseline comparison only uses records that provide a baseline_reward.

Fields

cumulative_reward: f64approximate_regret: f64baseline_cumulative_reward: f64reward_over_baseline: f64per_arm_pulls: Vec<u64>pending: usizecompleted: usizeexpired: usizemissing_feedback: usizeduplicate_feedback: usizerejected: usizegeneration_transitions: usizedrift_events: usizefeedback_latency: Option<FeedbackLatencySummary>deterministic_replay_digest: String

Stable, non-cryptographic FNV-1a digest of accepted replay facts.