Module traits

Module traits 

Core traits shared across RillML.

These traits are intentionally small and concrete. RillML avoids heavy trait-object based polymorphism in favor of concrete, serializable types for optimizers and losses.

Traits

Metric
An online evaluation metric.
OnlineBinaryClassifier
An online binary classifier that produces a probability in (0, 1).
OnlineRegressor
An online regressor that produces real-valued predictions.
OnlineStatistic
An online univariate statistic (mean, variance, etc.).
SparseClassifier
An online binary classifier that accepts sparse features.
SparseRegressor
An online regressor that accepts sparse features.
Transformer
A stateful feature transformer.