pub struct BinaryLogLoss { /* private fields */ }Expand description
Binary cross-entropy (log) loss.
Implementations
Sourceimpl BinaryLogLoss
impl BinaryLogLoss
Sourcepub fn with_epsilon(epsilon: f64) -> Result<Self, RillError>
pub fn with_epsilon(epsilon: f64) -> Result<Self, RillError>
Create a new log loss with a custom epsilon.
Sourcepub fn loss(&self, probability: f64, target: bool) -> f64
pub fn loss(&self, probability: f64, target: bool) -> f64
Compute the log loss given a probability and boolean target.
Sourcepub fn gradient_wrt_logit(&self, probability: f64, target: bool) -> f64
pub fn gradient_wrt_logit(&self, probability: f64, target: bool) -> f64
Gradient of the loss w.r.t. the logit z = log(p / (1 - p)).
This equals p - y where p = sigmoid(z).