pub struct ExponentiallyWeightedMeanRegressor { /* private fields */ }Expand description
A regressor that predicts an exponentially weighted mean of targets.
Suitable when recent observations are more relevant than older ones.
Implementations