Feature preprocessing transformers.
All transformers maintain per-feature online statistics and use O(d)
memory where d is the feature dimension.
Structs
- Clipper
- A simple element-wise clipper that bounds feature values to a fixed range.
- Constant
Imputer - Replaces
NaNvalues with a constant. - Constant
Imputer Config - Configuration for
ConstantImputer. - Forward
Fill - Replaces
NaNvalues with the last observed non-NaN value. - Frequency
Encoder - Online frequency encoder for string features.
- Mean
Imputer - Replaces
NaNvalues with the per-feature running mean. - MinMax
Scaler - Online min-max scaler that scales features to a configurable range.
- Missing
Indicator - Adds a missing-value indicator for each feature.
- OneHot
Encoder - Online one-hot encoder for string features.
- Ordinal
Encoder - Online ordinal encoder for string features.
- Standard
Scaler - Online standard scaler that standardizes features to approximately zero mean and unit variance.
- Standard
Scaler Config - Configuration for
StandardScaler.