pub struct MinMaxScaler { /* private fields */ }Expand description
Online min-max scaler that scales features to a configurable range.
When a feature has not been observed, transform returns the original
value. When a feature is constant (min == max), the output is the
midpoint of the target range to avoid NaN.
Implementations
Sourceimpl MinMaxScaler
impl MinMaxScaler