Missing value indicator transformer.
For each input feature, appends a binary indicator (1.0 if NaN, 0.0 otherwise). Output dimension = 2 * input dimension.
This transformer accepts NaN values in its input, unlike most other transformers.
Structs
- Missing
Indicator - Adds a missing-value indicator for each feature.